@@ -4,11 +4,11 @@ from __future__ import unicode_literals
 
 from django.contrib import admin
 from django.core import urlresolvers
-from django.conf import settings as django_settings
 from django.utils.translation import ugettext as _
 
-from contact_form.models import *
 from contact_form.conf import settings
+from contact_form.models import *
+
 
 try:
     from modeltranslation.admin import TranslationAdmin
@@ -21,7 +21,7 @@ except ImportError:
 
 
 class SubjectAdmin(SubjectBaseAdmin):
-    if hasattr(django_settings, 'SITE_ID') and settings.CONTACT_FORM_USE_SITES:
+    if hasattr(settings, 'SITE_ID') and settings.CONTACT_FORM_USE_SITES:
         list_display = ('title', 'department_url', 'site')
     else:
         list_display = ('title', 'department_url')
